%bcond_with bootstrap

Name:           modello
Version:        2.0.0
Release:        %mkrel 2
Group:          Development/Java
Summary:        Modello Data Model toolkit
# The majority of files are under MIT license, but some of them are ASL 2.0.
# Some parts of the project are derived from the Exolab project,
# and are licensed under a 5-clause BSD license.
License:        MIT and ASL 2.0 and BSD
URL:            https://codehaus-plexus.github.io/modello

Source0:        https://repo1.maven.org/maven2/org/codehaus/%{name}/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        https://www.apache.org/licenses/LICENSE-2.0.txt

Patch0:         0001-Remove-dependency-on-Jsoup.patch

BuildArch:      noarch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-compiler-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-compiler-javac)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.sonatype.plexus:plexus-build-api)
BuildRequires:  mvn(org.sonatype.sisu:sisu-guice::no_aop:)
%endif

# Explicit javapackages-tools requires since modello script uses
# /usr/share/java-utils/java-functions
Requires:         javapackages-tools

%description
Modello is a Data Model toolkit in use by the Apache Maven Project.

Modello is a framework for code generation from a simple model.
Modello generates code from a simple model format based on a plugin
architecture, various types of code and descriptors can be generated
from the single model, including Java POJOs, XML
marshallers/unmarshallers, XSD and documentation.

%package        javadoc
Summary:        Javadoc for %{name}

%description    javadoc
API documentation for %{name}.

%prep
%setup -q
%patch0 -p1
cp -p %{SOURCE1} LICENSE
# We don't generate site; don't pull extra dependencies.
%pom_remove_plugin :maven-site-plugin

%pom_remove_dep :jackson-bom
%pom_disable_module modello-plugin-jackson modello-plugins
%pom_disable_module modello-plugin-jsonschema modello-plugins
%pom_remove_dep :modello-plugin-jackson modello-maven-plugin
%pom_remove_dep :modello-plugin-jsonschema modello-maven-plugin

%pom_disable_module modello-plugin-snakeyaml modello-plugins
%pom_remove_dep :modello-plugin-snakeyaml modello-maven-plugin

%build
# skip tests because we have too old xmlunit in Fedora now (1.0.8)
%mvn_build -f

%install
%mvn_install

%jpackage_script org.codehaus.modello.ModelloCli "" "" modello:org.eclipse.sisu.plexus:org.eclipse.sisu.inject:google-guice-no_aop:atinject:plexus-containers/plexus-component-annotations:plexus/classworlds:plexus/utils:plexus/plexus-build-api:guava:plexus-compiler/plexus-compiler-api:plexus-compiler/plexus-compiler-javac %{name} true

%files -f .mfiles
%doc LICENSE
%{_bindir}/modello

%files javadoc -f .mfiles-javadoc
%doc LICENSE


%changelog
* Mon Jul 25 2022 neoclust <neoclust> 2.0.0-2.mga9
+ Revision: 1871092
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 2.0.0-1.mga9
+ Revision: 1870793
- New version 2.0.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Oct 27 2020 tv <tv> 0:1.11-2.mga8
+ Revision: 1639791
- Rebuild for JDK 11

* Wed Aug 19 2020 neoclust <neoclust> 0:1.11-1.mga8
+ Revision: 1615525
- New version 1.11

* Sun Feb 16 2020 umeabot <umeabot> 0:1.10.0-2.mga8
+ Revision: 1536136
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 0:1.10.0-1.mga8
+ Revision: 1453317
- Update to version 1.10.0

* Thu Sep 20 2018 umeabot <umeabot> 0:1.9.1-2.mga7
+ Revision: 1279945
- Mageia 7 Mass Rebuild

* Thu Apr 12 2018 kekepower <kekepower> 0:1.9.1-1.mga7
+ Revision: 1217842
- BR jsoup
- Update to version 1.9.1

* Thu May 18 2017 neoclust <neoclust> 0:1.8.3-5.mga6
+ Revision: 1102874
- Regenerate build-requires
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 0:1.8.3-3.mga6
+ Revision: 977261
- First rebuild of the java stack
- sync package modello with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0:1.8.1-3.mga5
+ Revision: 748165
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 pterjan <pterjan> 0:1.8.1-1.mga5
+ Revision: 674058
- Add 2 missing BuildRequires
-1.8.1
- Sync with fedora
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Tue Jul 09 2013 dmorgan <dmorgan> 0:1.7-2.mga4
+ Revision: 452273
- New version 1.7

* Sat Jan 12 2013 umeabot <umeabot> 0:1.5-2.mga3
+ Revision: 360184
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 0:1.5-1.mga3
+ Revision: 324898
- Java Stack Mass Rebuild
+ gil <gil>
- changed groups
- update to 1.5

* Thu Apr 28 2011 dmorgan <dmorgan> 0:1.4.1-3.mga1
+ Revision: 92940
- Rebuild after bootstrapping
- imported package modello


* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jan 26 2011 Alexander Kurtakov <akurtako@redhat.com> 0:1.4.1-1
- Update to upstream 1.4.1.

* Wed Dec  1 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:1.4-3
- Fix pom filenames (remove poms of integration tests) Resolves rhbz#655818
- Use jpackage_script macro to generate script

* Thu Aug 26 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:1.4-2
- Remove dtdparser BR/R

* Tue Jul 20 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0:1.4-1
- Update to latest upstream version
- Re-enable javadoc generation
- Remove old workarounds/patches

* Mon May 24 2010 Yong Yang <yyang@redhat.com> 1.1-2
- Fix JPP pom name
- Disable javadoc:javadoc due to the failure of maven-doxia

* Mon May 24 2010 Yong Yang <yyang@redhat.com> 1.1-1
- Upgrade to 1.1

* Fri May 21 2010 Yong Yang <yyang@redhat.com> 1.0.1-1
- Upgrade to 1.0.1

* Thu Aug 20 2009 Andrew Overholt <overholt@redhat.com> 1.0-0.4.a15.0.1
- Update to alpha 15 courtesy Deepak Bhole

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-0.3.a8.4.4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.0-0.2.a8.4.4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jul  9 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0:1.0-0.1.a8.4.4
- drop repotag

* Tue Mar 20 2007 Matt Wringe <wringe@redhat.com> 0:1.0-0.1.a8.4jpp.3
- disable gcj support

* Tue Mar 13 2007 Matt Wringe <mwringe@redhat.com> 0:1.0-0.1.a8.4jpp.2
- Change license to MIT to reflex the actual license specified in the
  source headers.
- fix various rpmlint issues

* Mon Feb 26 2007 Tania Bento <tbento@redhat.com> 0:1.0-0.1.a8.4jpp.1
- Fixed %%Release.
- Fixed %%License.
- Fixed %%BuildRoot.
- Removed %%Vendor.
- Removed %%Distribution.
- Defined _with_gcj_support and gcj_support.
- Fixed instructions on how to generate the source drop.

* Fri Dec 01 2006 Deepak Bhole <dbhole@redhat.com> 1.0-0.a8.4jpp
- Added an obsoletes for older versions of the plugin

* Thu Oct 19 2006 Deepak Bhole <dbhole@redhat.com> 1.0-0.a8.3jpp
- Update for maven2 9jpp
- Merge maven-plugin subpackage into the main one

* Mon Sep 11 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.0-0.a8.2jpp
- Add gcj_support option
- Add post/postun Requires for javadoc
- Don't omit maven-plugin upload

* Fri Jun 23 2006 Deepak Bhole <dbhole@redhat.com> - 0:1.0-0.a8.1jpp
- Upgrade to 1.0-alpha-8
- Remove ant build, add maven2 build

* Thu Jun 01 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0-0.a4.2jpp
- First JPP 1.7 build

* Mon Nov 07 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.0-0.a4.1jpp
- First JPackage build
